# To Do - Coisas a Fazer

- translate: Adicionar suporte a "BEZIER.SURFACE" para a tradução de .dat para .svg.
- translate: Adicionar suporte a NURBS para a tradução de .dat para .svg.
- translate: Adicionar suporte a elementos 3D e 1D para a tradução de .dat para .svg
- translate: Adicionar tradução de .pos para .svg.
- translate: Adicionar tradução de .pos para algum formato de um sistema de pós-processamento (ParaView, gmesh, VTK). 
- translate: Adicionar suporte a Materiais e Seções na tradução de .inp para .dat.
- reorder: Adicionar mais métodos de reordenação (ex: Sloan)
- generate: Mudar forma de gerar laminas inteligentes (deve haver um algoritmo mais eficiente do que o implementado)
- interface: Adicionar prompts para comandos caso parâmetros não sejam passados.
- Implementar novo comando "view" (Visualizador simples de modelos .dat e resultados .pos)